# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkopenanalytics_open.endpoint import endpoint_data

class CreateVirtualClusterForSparkRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'openanalytics-open', '2018-06-19', 'CreateVirtualClusterForSpark','openanalytics')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DefaultExecutorSpecName(self):
		return self.get_body_params().get('DefaultExecutorSpecName')

	def set_DefaultExecutorSpecName(self,DefaultExecutorSpecName):
		self.add_body_params('DefaultExecutorSpecName', DefaultExecutorSpecName)

	def get_MaxMemory(self):
		return self.get_body_params().get('MaxMemory')

	def set_MaxMemory(self,MaxMemory):
		self.add_body_params('MaxMemory', MaxMemory)

	def get_SparkModuleReleaseName(self):
		return self.get_body_params().get('SparkModuleReleaseName')

	def set_SparkModuleReleaseName(self,SparkModuleReleaseName):
		self.add_body_params('SparkModuleReleaseName', SparkModuleReleaseName)

	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_DefaultExecutorNumbers(self):
		return self.get_body_params().get('DefaultExecutorNumbers')

	def set_DefaultExecutorNumbers(self,DefaultExecutorNumbers):
		self.add_body_params('DefaultExecutorNumbers', DefaultExecutorNumbers)

	def get_MaxCpu(self):
		return self.get_body_params().get('MaxCpu')

	def set_MaxCpu(self,MaxCpu):
		self.add_body_params('MaxCpu', MaxCpu)

	def get_Name(self):
		return self.get_body_params().get('Name')

	def set_Name(self,Name):
		self.add_body_params('Name', Name)

	def get_DefaultDriverSpecName(self):
		return self.get_body_params().get('DefaultDriverSpecName')

	def set_DefaultDriverSpecName(self,DefaultDriverSpecName):
		self.add_body_params('DefaultDriverSpecName', DefaultDriverSpecName)